{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Global settings" %}{% endblock %}
{% block bodyclass %}menu-global-settings{% endblock %}
{% block content %}

    {% include "wagtailadmin/shared/header.html" with title="Global settings" subtitle="Choose" icon="cogs" %}

    <div class="nice-padding">
        {% if has_global_settings %}

            <ul class="listing">
                {% for content_type, model_type in global_settings_list %}
                    <li>
                        <div class="row row-flush title">
                            <h2>
                                <a href="{% url 'wagtail_global_settings_edit' pk=content_type.pk %}" class="col6">
                                    {{ model_type }}
                                </a>
                            </h2>
                            <small class="col6">{{ content_type.app_label|title }}</small>
                        </div>
                    </li>
                {% endfor %}
            </ul>
        {% else %}
            <p>{% blocktrans %}There are no global settings to be edited!{% endblocktrans %}</p>
        {% endif %}
    </div>
{% endblock %}
