{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Site settings" %}{% endblock %}
{% block bodyclass %}menu-site-settings{% endblock %}
{% block content %}

    {% include "wagtailadmin/shared/header.html" with title="Site settings" subtitle="Choose site" icon="cogs" %}

    <div class="nice-padding">
        {% if has_site_settings %}

            <ul class="listing">
                {% for site in sites_list %}
                    <li>
                        <div class="row row-flush title">
                            <h2>
                                <a href="{% url 'wagtail_site_settings_choose' pk=site.pk %}" class="col6">
                                    {{ site.hostname }}{% if site.port != 80 %}:{{ site.port }}{% endif %}
                                </a>
                            </h2>
                            {% if site.is_default_site %}<small class="col6">{% trans "DEFAULT" %}</small>{% endif %}
                        </div>
                    </li>
                {% endfor %}
            </ul>
        {% else %}
            <p>{% blocktrans %}There are no sites with settings to be edited!{% endblocktrans %}</p>
        {% endif %}
    </div>
{% endblock %}
