{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Edit site settings" %}{% endblock %}
{% block bodyclass %}menu-site-settings{% endblock %}
{% block content %}

    {% trans "Edit site settings" as new_str %}
    {% include "wagtailadmin/shared/header.html" with title=new_str subtitle=model_name icon="cogs" %}

	<div class="nice-padding">
		<h1>{{ model_name }} <small>({{ site.hostname }}{% if site.port != 80 %}:{{ site.port }}{% endif %})</small></h1>
	</div>
	<br/>
    <form action="{% url 'wagtail_site_settings_edit' pk=site.pk ct_pk=content_type.pk %}" method="POST">
        {% csrf_token %}
        {{ edit_handler.render_form_content }}

		<br/>
		<div class="nice-padding"><input type="submit" value="{% trans 'Save' %}" /></div>
    </form>
{% endblock %}

{% block extra_css %}
    {% include "wagtailadmin/pages/_editor_css.html" %}
{% endblock %}
{% block extra_js %}
    {% include "wagtailadmin/pages/_editor_js.html" %}
{% endblock %}
